package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.DebitInfors;
import com.ruoyi.invest.domain.dto.DebitInforsDto;
import com.ruoyi.invest.domain.vo.DebitInforsVo;

/**
 * 信贷产品管理Service接口
 *
 * @author tianyongbao
 * @date 2024-04-09
 */
public interface IDebitInforsService
{
    /**
     * 查询信贷产品管理
     *
     * @param id 信贷产品管理主键
     * @return 信贷产品管理
     */
    public DebitInforsVo selectDebitInforsById(Long id);

    /**
     * 查询信贷产品管理列表
     *
     * @param debitInforsDto 信贷产品管理
     * @return 信贷产品管理集合
     */
    public List<DebitInforsVo> selectDebitInforsList(DebitInforsDto debitInforsDto);

    /**
     * 新增信贷产品管理
     *
     * @param debitInfors 信贷产品管理
     * @return 结果
     */
    public int insertDebitInfors(DebitInfors debitInfors);

    /**
     * 修改信贷产品管理
     *
     * @param debitInfors 信贷产品管理
     * @return 结果
     */
    public int updateDebitInfors(DebitInfors debitInfors);

    /**
     * 批量删除信贷产品管理
     *
     * @param ids 需要删除的信贷产品管理主键集合
     * @return 结果
     */
    public int deleteDebitInforsByIds(Long[] ids);

    /**
     * 删除信贷产品管理信息
     *
     * @param id 信贷产品管理主键
     * @return 结果
     */
    public int deleteDebitInforsById(Long id);
}
