package com.ruoyi.invest.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.invest.domain.DebitInfors;
import com.ruoyi.invest.domain.vo.DebitInforsVo;
import com.ruoyi.invest.domain.dto.DebitInforsDto;
import com.ruoyi.invest.service.IDebitInforsService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 信贷产品管理Controller
 *
 * @author tianyongbao
 * @date 2024-04-09
 */
@Api(tags=" 信贷产品管理")
@RestController
@RequestMapping("/debitInfors")
public class DebitInforsController extends BaseController
{
    @Resource
    private IDebitInforsService debitInforsService;

    /**
     * 查询信贷产品管理列表
     */
    @ApiOperation(value="查询信贷产品管理列表",response = DebitInforsVo.class)
    @RequiresPermissions("invest:debitInfors:list")
    @GetMapping("/list")
    public TableDataInfo list(DebitInforsDto debitInforsDto)
    {
        startPage();
        List<DebitInforsVo> list = debitInforsService.selectDebitInforsList(debitInforsDto);
        return getDataTable(list);
    }

    /**
     * 导出信贷产品管理列表
     */
    @ApiOperation(value="导出信贷产品管理列表")
    @RequiresPermissions("invest:debitInfors:export")
    @Log(title = "信贷产品管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DebitInforsDto debitInforsDto)
    {
        List<DebitInforsVo> list = debitInforsService.selectDebitInforsList(debitInforsDto);
        ExcelUtil<DebitInforsVo> util = new ExcelUtil<DebitInforsVo>(DebitInforsVo.class);
        util.exportExcel(response, list, "信贷产品管理数据");
    }

    /**
     * 获取信贷产品管理详细信息
     */
    @ApiOperation(value="获取信贷产品管理详细信息")
    @RequiresPermissions("invest:debitInfors:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(debitInforsService.selectDebitInforsById(id));
    }

    /**
     * 新增信贷产品管理
     */
    @ApiOperation(value="新增信贷产品管理")
    @RequiresPermissions("invest:debitInfors:add")
    @Log(title = "信贷产品管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DebitInfors debitInfors)
    {
        return toAjax(debitInforsService.insertDebitInfors(debitInfors));
    }

    /**
     * 修改信贷产品管理
     */
    @ApiOperation(value="修改信贷产品管理")
    @RequiresPermissions("invest:debitInfors:edit")
    @Log(title = "信贷产品管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DebitInfors debitInfors)
    {
        return toAjax(debitInforsService.updateDebitInfors(debitInfors));
    }

    /**
     * 删除信贷产品管理
     */
    @ApiOperation(value="删除信贷产品管理")
    @RequiresPermissions("invest:debitInfors:remove")
    @Log(title = "信贷产品管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(debitInforsService.deleteDebitInforsByIds(ids));
    }
}
